@@ -26,7 +26,7 @@ def from_json_dict(root):
 
 
 def register_definition(
- 			name,
+ 			name=Utils.Empty,
 			aliases=Utils.Empty,
 			description=Utils.Empty,
 			data_type=Utils.Empty,
@@ -50,7 +50,7 @@ def register_definition(
 			examples=examples,
 			nullable=nullable,
 			deprecated=deprecated,
-			internal=is_internal,
+			internal=internal,
 			rules=rules,
 			meta=meta,
 			dependency_resolver=dependency_resolver
