@@ -136,7 +136,7 @@ class Definition:
 		######
 		self.name = Config.definition_name_strategy.create_name(self, self.name)
 		if self.name is None:
-			ConfigApi.exception_factory.create_input_error(
+			Config.exception_factory.create_input_error(
 					'<unset>', 'Definition name cannot be None (description={0})'.format(self.description)
 				)
 		# Aliases
@@ -316,10 +316,11 @@ class Definition:
 	def get_name(self):
 		return self.name
 
-	def get_description(self, delim=' '):
+	def get_description(self, delim=' ', cat_rules=False):
 		result = self.description
-		if self.rules is not None and len(self.rules) > 0:
-			result = result + delim + delim.join([rule.get_description() for rule in self.rules])
+		if cat_rules is True:
+			if self.rules is not None and len(self.rules) > 0:
+				result = result + delim + delim.join([rule.get_description() for rule in self.rules])
 		return result
 
 	def get_aliases(self):
