@@ -75,7 +75,7 @@ class DefinitionExists(Rule):
 class AsInt(Rule):
 	def __init__(self):
 		super().__init__(
-				description='Must be an integer.',
+				description='Integer or string formatted as integer.',
 				callback=Normalize.as_int
 			)
 
@@ -86,7 +86,7 @@ class AsInt(Rule):
 class IntGte(Rule):
 	def __init__(self, minimum):
 		super().__init__(
-				description='Must be integer greater than or equal to {0}.'.format(minimum),
+				description='Greater than or equal to {0}.'.format(minimum),
 				callback=Normalize.as_int_greater_than_or_equal_to,
 				config={'minimum':minimum}
 			)
@@ -98,7 +98,7 @@ class IntGte(Rule):
 class IntLte(Rule):
 	def __init__(self, maximum):
 		super().__init__(
-				description='Must be integer less than or equal to {0}.'.format(maximum),
+				description='Less than or equal to {0}.'.format(maximum),
 				callback=Normalize.as_int_less_than_or_equal_to,
 				config={'maximum':maximum}
 			)
@@ -111,7 +111,7 @@ class IntLte(Rule):
 class FloatGte(Rule):
 	def __init__(self, minimum):
 		super().__init__(
-				description='Must be float greater than or equal to {0}.'.format(minimum),
+				description='Greater than or equal to {0}.'.format(minimum),
 				callback=Normalize.as_float_greater_than_or_equal_to,
 				config={'minimum':minimum}
 			)
@@ -124,7 +124,7 @@ class FloatGte(Rule):
 class FloatLte(Rule):
 	def __init__(self, maximum):
 		super().__init__(
-				description='Must be float less than or equal to {0}.'.format(maximum),
+				description='Less than or equal to {0}.'.format(maximum),
 				callback=Normalize.as_float_less_than_or_equal_to,
 				config={'maximum':maximum}
 			)
@@ -137,7 +137,7 @@ class FloatLte(Rule):
 class FloatLt(Rule):
 	def __init__(self, maximum):
 		super().__init__(
-				description='Must be float less than {0}.'.format(maximum),
+				description='Less than {0}.'.format(maximum),
 				callback=Normalize.as_float_less_than,
 				config={'maximum':maximum}
 			)
@@ -152,7 +152,7 @@ class FloatLt(Rule):
 class MatchRegex(Rule):
 	def __init__(self, rex, flags=0, boundaries=[]): # re.IGNORECASE
 		super().__init__(				
-				description='Must match expression {0}'.format(rex),
+				description='Matches {0}'.format(rex),
 				callback=Normalize.as_str_matching_regex,
 				config={'rex':rex, 'flags':flags},
 				boundaries=boundaries
@@ -165,7 +165,7 @@ class MatchRegex(Rule):
 class StrWithMinLen(Rule):
 	def __init__(self, min_len):
 		super().__init__(
-				description='Must be at least {0} characters long.'.format(min_len),
+				description='At least {0} characters long.'.format(min_len),
 				callback=Normalize.as_str_with_min_len,
 				config={'min_len':min_len}
 			)
@@ -178,7 +178,7 @@ class StrWithMinLen(Rule):
 class StrWithMaxLen(Rule):
 	def __init__(self, max_len):
 		super().__init__(
-				description='Must be no longer than {0} characters.'.format(max_len),
+				description='No longer than {0} characters.'.format(max_len),
 				callback=Normalize.as_str_with_max_len,
 				config={'max_len':max_len}
 			)
@@ -191,7 +191,7 @@ class StrWithMaxLen(Rule):
 class StrWithinInclusiveLenRange(Rule):
 	def __init__(self, min_len, max_len):
 		super().__init__(
-				description='Must be at least {0} and no more than {1} characters.'.format(min_len, max_len),
+				description='At least {0} and no more than {1} characters.'.format(min_len, max_len),
 				callback=Normalize.as_str_within_inclusive_len_range,
 				config={'max_len':max_len, 'min_len':min_len}
 			)
@@ -207,12 +207,12 @@ class StrWithinInclusiveLenRange(Rule):
 
 class ValueInSet(Rule):
 	def __init__(self, values):
-		desc = 'Must be one of: '
+		desc = 'One of: '
 		if len(values) == 1:
-			desc = 'Must be: '
+			desc = 'Equal to: '
 		desc = desc + ', '.join(["'{0}'".format(str(entry)) for entry in values])
 		if isinstance(values, dict):
-			desc = desc + ' (where {0})'.format(', '.join(["'{0}'='{1}'".format(str(entry), values[entry]) for entry in values]))
+			desc = desc + ' ({0})'.format(', '.join(["'{0}'='{1}'".format(str(entry), values[entry]) for entry in values]))
 		desc = desc + '.'
 		super().__init__(
 				description=desc,
